@@ -14,7 +14,7 @@ from doorstop.core.item import Item
 from doorstop.core.document import Document
 from doorstop.common import DoorstopError
 
-from doorstop.core.test import ROOT, FILES, EMPTY, NEW
+from doorstop.core.test import ENV, REASON, ROOT, FILES, EMPTY, NEW
 
 
 class MockItem(Item, Mock):  # pylint: disable=R0904
@@ -71,7 +71,7 @@ class TestDocument(unittest.TestCase):  # pylint: disable=R0904
         self.document.prefix = 'SRD'
         self.document.digits = 5
         self.document.save()
-        text = "settings:\n  digits: 5\n  prefix: SRD\n"
+        text = "settings:\n  digits: 5\n  parent: SYS\n  prefix: SRD\n"
         self.assertEqual(text, self.document._file)
 
     def test_save_parent(self):
@@ -83,7 +83,7 @@ class TestDocument(unittest.TestCase):  # pylint: disable=R0904
     def test_str(self):
         """Verify documents can be converted to strings."""
         path = os.path.join('doorstop', 'core', 'test', 'files')
-        text = "_REQ (@{}{})".format(os.sep, path)
+        text = "REQ (@{}{})".format(os.sep, path)
         self.assertEqual(text, str(self.document))
 
     def test_ne(self):
@@ -94,7 +94,7 @@ class TestDocument(unittest.TestCase):  # pylint: disable=R0904
         """Verify the items in a document can be accessed."""
         items = self.document.items
         logging.debug("items: {}".format(items))
-        self.assertEqual(3, len(items))
+        self.assertEqual(4, len(items))
 
     @patch('doorstop.core.document.Document', MockDocument)
     def test_new(self):
@@ -116,22 +116,37 @@ class TestDocument(unittest.TestCase):  # pylint: disable=R0904
         """Verify an exception is raised on an invalid document."""
         self.assertRaises(DoorstopError, Document, EMPTY)
 
+    def test_depth(self):
+        """Verify the maximum item level depth can be determined."""
+        self.assertEqual(3, self.document.depth)
+
+    def test_next(self):
+        """Verify the next item number can be determined."""
+        self.assertEqual(4, self.document.next)
+
     @patch('doorstop.core.item.Item.new')
     def test_add(self, mock_new):
         """Verify an item can be added to a document."""
         self.document.add()
-        mock_new.assert_called_once_with(FILES, ROOT, '_REQ', 2, 4, (2, 2))
+        mock_new.assert_called_once_with(FILES, ROOT, 'REQ', 2, 4, (2, 2))
 
     @patch('doorstop.core.item.Item.new')
     def test_add_empty(self, mock_new):
         """Verify an item can be added to an new document."""
         document = MockDocument(NEW, ROOT)
         self.assertIsNot(None, document.add())
-        mock_new.assert_called_once_with(NEW, ROOT, '_NEW', 5, 1, None)
+        mock_new.assert_called_once_with(NEW, ROOT, 'NEW', 5, 1, None)
 
-    def test_check(self):
+    @patch('doorstop.core.item.Item.check')
+    def test_check(self, mock_check):
         """Verify a document can be validated."""
         self.document.check()
+        self.assertEqual(4, mock_check.call_count)
+
+    @unittest.skipUnless(os.getenv(ENV), REASON)
+    def test_check_long(self):
+        """Verify a document can be validated (long)."""
+        self.document.check()
 
 
 class TestModule(unittest.TestCase):  # pylint: disable=R0904
