@@ -126,14 +126,14 @@ class TestTree(unittest.TestCase):  # pylint: disable=R0904
 
     def setUp(self):
         self.tree = Tree(Document(SYS))
-        self.tree.place(Document(FILES))
+        self.tree._place(Document(FILES))  # pylint: disable=W0212
 
     @patch('doorstop.core.vcs.find_root', Mock(return_value=EMPTY))
     def test_palce_empty(self):
         """Verify a document can be placed in an empty tree."""
         tree = build(EMPTY)
         doc = MockDocument.new(os.path.join(EMPTY, 'temp'), EMPTY, 'TEMP')
-        tree.place(doc)
+        tree._place(doc)  # pylint: disable=W0212
         self.assertEqual(1, len(tree))
 
     @patch('doorstop.core.vcs.find_root', Mock(return_value=EMPTY))
@@ -142,7 +142,7 @@ class TestTree(unittest.TestCase):  # pylint: disable=R0904
         tree = build(EMPTY)
         doc = MockDocument.new(os.path.join(EMPTY, 'temp'), EMPTY, 'TEMP',
                                parent='REQ')
-        self.assertRaises(DoorstopError, tree.place, doc)
+        self.assertRaises(DoorstopError, tree._place, doc)  # pylint: disable=W0212
 
     @patch('doorstop.core.document.Document.check')
     def test_check(self, mock_check):
@@ -245,13 +245,18 @@ class TestTree(unittest.TestCase):  # pylint: disable=R0904
         mock_lock.assert_called_once_with(path)
 
     def test_edit_unknown_prefix(self):
-        """Verify an exception is rasied for an unknown prefix (document)."""
+        """Verify an exception is raised for an unknown prefix (document)."""
         self.assertRaises(DoorstopError, self.tree.edit, 'unknown1')
 
     def test_edit_unknown_number(self):
-        """Verify an exception is rasied for an unknown number."""
+        """Verify an exception is raised for an unknown number."""
         self.assertRaises(DoorstopError, self.tree.edit, 'req9999')
 
+    def test_find_item(self):
+        """Verify an item can be found by exact ID."""
+        item = self.tree.find_item('req2-001')
+        self.assertIsNot(None, item)
+
 
 class TestModule(unittest.TestCase):  # pylint: disable=R0904
     """Unit tests for the doorstop.core.tree module."""  # pylint: disable=C0103
