@@ -11,7 +11,7 @@ from itertools import chain
 
 from doorstop.common import DoorstopError
 from doorstop.core.document import Document
-from doorstop.core.item import Item
+from doorstop.core.item import split_id
 from doorstop.core import vcs
 
 
@@ -86,7 +86,7 @@ class Tree(object):
             count = len(unplaced)
             for doc in list(unplaced):
                 try:
-                    tree.place(doc)
+                    tree._place(doc)  # pylint: disable=W0212
                 except DoorstopError as error:
                     logging.debug(error)
                 else:
@@ -100,14 +100,7 @@ class Tree(object):
 
         return tree
 
-    @property
-    def vcs(self):
-        """Get the working copy."""
-        if self._vcs is None:
-            self._vcs = vcs.load(self.root)
-        return self._vcs
-
-    def place(self, doc):
+    def _place(self, doc):
         """Attempt to place the Document in the current tree.
 
         @param doc: Document to add
@@ -119,7 +112,7 @@ class Tree(object):
 
             # Tree is empty
             if doc.parent:
-                msg = "no parent for: {}".format(doc)
+                msg = "unknown parent for {}: {}".format(doc, doc.parent)
                 raise DoorstopError(msg)
             self.document = doc
 
@@ -134,26 +127,25 @@ class Tree(object):
             # Search for the parent
             for child in self.children:
                 try:
-                    child.place(doc)
+                    child._place(doc)  # pylint: disable=W0212
                 except DoorstopError:
                     pass  # the error is raised later
                 else:
                     break
             else:
-                msg = "no parent for: {}".format(doc)
+                msg = "unknown parent for {}: {}".format(doc, doc.parent)
                 raise DoorstopError(msg)
 
-    def check(self):
-        """Confirm the document hiearchy is valid.
+    # attributes #############################################################
 
-        @return: indication that hiearchy is valid
+    @property
+    def vcs(self):
+        """Get the working copy."""
+        if self._vcs is None:
+            self._vcs = vcs.load(self.root)
+        return self._vcs
 
-        @raise DoorstopError: on issue
-        """
-        logging.info("checking document tree...")
-        for document in self:
-            document.check(tree=self, ignored=self.vcs.ignored)
-        return True
+    # actions ################################################################
 
     def new(self, path, prefix, parent=None, digits=None):
         """Create a new document and add it to the tree.
@@ -170,7 +162,7 @@ class Tree(object):
         document = Document.new(path, self.root, prefix,
                                 parent=parent, digits=digits)
         try:
-            self.place(document)
+            self._place(document)
         except DoorstopError:
             msg = "deleting unplaced directory {}...".format(document.path)
             logging.debug(msg)
@@ -290,7 +282,9 @@ class Tree(object):
         @raise DoorstopError: if the item cannot be found
         """
         _kind = (' ' + kind) if kind else kind
-        prefix, number = Item.split_id(identifier)
+
+        # Search using the prefix and number
+        prefix, number = split_id(identifier)
         for document in self:
             if document.prefix.lower() == prefix.lower():
                 for item in document:
@@ -302,8 +296,26 @@ class Tree(object):
         else:
             logging.info("no matching{} prefix: {}".format(_kind, prefix))
 
+        # Fall back to a search using the exact ID
+        for document in self:
+            for item in document:
+                if item.id.lower() == identifier.lower():
+                    return item
+
         raise DoorstopError("no matching{} ID: {}".format(_kind, identifier))
 
+    def check(self):
+        """Confirm the document hiearchy is valid.
+
+        @return: indication that hiearchy is valid
+
+        @raise DoorstopError: on issue
+        """
+        logging.info("checking document tree...")
+        for document in self:
+            document.check(tree=self, ignored=self.vcs.ignored)
+        return True
+
 
 def _open(path, tool=None):  # pragma: no cover, integration test
     """Open the text file using the default editor."""
@@ -351,9 +363,9 @@ def build(cwd=None, root=None):
     # Build the document tree
     if not documents:
         logging.warning("no documents found in: {}".format(root))
-    logging.info("building document tree...")
+    logging.info("building tree...")
     tree = Tree.from_list(documents, root=root)
-    logging.info("final document tree: {}".format(tree))
+    logging.info("final tree: {}".format(tree))
     return tree
 
 
